==> jc-1.4.0.tar.gz: javax/net/ssl/SSLProtocolException.h <==
// public class javax.net.ssl.SSLProtocolException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class d1cfa534e15939af javax_net_ssl_SSLException
// @dep_class 2c7096b01b099171 javax_net_ssl_SSLProtocolException

// header file dependencies
// @dep_header javax_net_ssl_SSLException

#include "javax/net/ssl/SSLException.h"

#ifndef _JC_javax_net_ssl_SSLProtocolException_H_
#define _JC_javax_net_ssl_SSLProtocolException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_net_ssl_SSLProtocolException$sub_refs	_jc_javax_net_ssl_SSLProtocolException$sub_refs;
typedef struct _jc_javax_net_ssl_SSLProtocolException$sub_nonrefs	_jc_javax_net_ssl_SSLProtocolException$sub_nonrefs;
typedef struct _jc_javax_net_ssl_SSLProtocolException$refs	_jc_javax_net_ssl_SSLProtocolException$refs;
typedef struct _jc_javax_net_ssl_SSLProtocolException$nonrefs	_jc_javax_net_ssl_SSLProtocolException$nonrefs;
typedef struct _jc_javax_net_ssl_SSLProtocolException$object	_jc_javax_net_ssl_SSLProtocolException$object;

typedef const struct _jc_javax_net_ssl_SSLProtocolException$vmethods	_jc_javax_net_ssl_SSLProtocolException$vmethods;
typedef const struct _jc_javax_net_ssl_SSLProtocolException$vtable	_jc_javax_net_ssl_SSLProtocolException$vtable;
typedef const struct _jc_javax_net_ssl_SSLProtocolException$vtype	_jc_javax_net_ssl_SSLProtocolException$vtype;

// Constructors
extern void _jc_javax_net_ssl_SSLProtocolException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_net_ssl_SSLProtocolException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_net_ssl_SSLProtocolException$vmethods {
};

// Vtable
struct _jc_javax_net_ssl_SSLProtocolException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_javax_net_ssl_SSLException$vmethods	javax_net_ssl_SSLException;
	_jc_javax_net_ssl_SSLProtocolException$vmethods	javax_net_ssl_SSLProtocolException;
};

// Vtype
struct _jc_javax_net_ssl_SSLProtocolException$vtype {
	_jc_type			type;
	_jc_javax_net_ssl_SSLProtocolException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLProtocolException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_net_ssl_SSLProtocolException$refs {
    _jc_javax_net_ssl_SSLProtocolException$sub_refs	javax_net_ssl_SSLProtocolException;
    _jc_javax_net_ssl_SSLException$sub_refs	javax_net_ssl_SSLException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLProtocolException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_ssl_SSLProtocolException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_javax_net_ssl_SSLException$sub_nonrefs	javax_net_ssl_SSLException;
    _jc_javax_net_ssl_SSLProtocolException$sub_nonrefs	javax_net_ssl_SSLProtocolException;
};

// Object instance structure
struct _jc_javax_net_ssl_SSLProtocolException$object {
	_jc_javax_net_ssl_SSLProtocolException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_ssl_SSLProtocolException$vtype	*vtype;
	_jc_javax_net_ssl_SSLProtocolException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_ssl_SSLProtocolException$vtype _jc_javax_net_ssl_SSLProtocolException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_ssl_SSLProtocolException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_ssl_SSLProtocolException$class_object;

#endif	/* _JC_javax_net_ssl_SSLProtocolException_H_ */

==> jc-1.4.6.tar.gz: javax/net/ssl/SSLProtocolException.h <==
// public class javax.net.ssl.SSLProtocolException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class d1cfa534e15939af javax_net_ssl_SSLException
// @dep_class 2c7096b01b099171 javax_net_ssl_SSLProtocolException

// header file dependencies
// @dep_header javax_net_ssl_SSLException

#include "javax/net/ssl/SSLException.h"

#ifndef _JC_javax_net_ssl_SSLProtocolException_H_
#define _JC_javax_net_ssl_SSLProtocolException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_net_ssl_SSLProtocolException$sub_refs	_jc_javax_net_ssl_SSLProtocolException$sub_refs;
typedef struct _jc_javax_net_ssl_SSLProtocolException$sub_nonrefs	_jc_javax_net_ssl_SSLProtocolException$sub_nonrefs;
typedef struct _jc_javax_net_ssl_SSLProtocolException$refs	_jc_javax_net_ssl_SSLProtocolException$refs;
typedef struct _jc_javax_net_ssl_SSLProtocolException$nonrefs	_jc_javax_net_ssl_SSLProtocolException$nonrefs;
typedef struct _jc_javax_net_ssl_SSLProtocolException$object	_jc_javax_net_ssl_SSLProtocolException$object;

typedef const struct _jc_javax_net_ssl_SSLProtocolException$vmethods	_jc_javax_net_ssl_SSLProtocolException$vmethods;
typedef const struct _jc_javax_net_ssl_SSLProtocolException$vtable	_jc_javax_net_ssl_SSLProtocolException$vtable;
typedef const struct _jc_javax_net_ssl_SSLProtocolException$vtype	_jc_javax_net_ssl_SSLProtocolException$vtype;

// Constructors
extern void _jc_javax_net_ssl_SSLProtocolException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_net_ssl_SSLProtocolException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_net_ssl_SSLProtocolException$vmethods {
};

// Vtable
struct _jc_javax_net_ssl_SSLProtocolException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_javax_net_ssl_SSLException$vmethods	javax_net_ssl_SSLException;
	_jc_javax_net_ssl_SSLProtocolException$vmethods	javax_net_ssl_SSLProtocolException;
};

// Vtype
struct _jc_javax_net_ssl_SSLProtocolException$vtype {
	_jc_type			type;
	_jc_javax_net_ssl_SSLProtocolException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLProtocolException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_net_ssl_SSLProtocolException$refs {
    _jc_javax_net_ssl_SSLProtocolException$sub_refs	javax_net_ssl_SSLProtocolException;
    _jc_javax_net_ssl_SSLException$sub_refs	javax_net_ssl_SSLException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLProtocolException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_ssl_SSLProtocolException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_javax_net_ssl_SSLException$sub_nonrefs	javax_net_ssl_SSLException;
    _jc_javax_net_ssl_SSLProtocolException$sub_nonrefs	javax_net_ssl_SSLProtocolException;
};

// Object instance structure
struct _jc_javax_net_ssl_SSLProtocolException$object {
	_jc_javax_net_ssl_SSLProtocolException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_ssl_SSLProtocolException$vtype	*vtype;
	_jc_javax_net_ssl_SSLProtocolException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_ssl_SSLProtocolException$vtype _jc_javax_net_ssl_SSLProtocolException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_ssl_SSLProtocolException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_ssl_SSLProtocolException$class_object;

#endif	/* _JC_javax_net_ssl_SSLProtocolException_H_ */
